@@ -26,8 +26,6 @@ describe 'basic aodh' do
         provider             => 'rabbitmqctl',
         require              => Class['rabbitmq'],
       }
-      # https://bugs.launchpad.net/aodh/+bug/1557154
-      Rabbitmq_user_permissions['aodh@/'] -> Service<| tag == 'aodh-service' |>
 
       class { '::aodh':
         debug                 => true,
@@ -46,6 +44,7 @@ describe 'basic aodh' do
       class { '::aodh::api':
         enabled      => true,
         service_name => 'httpd',
+        sync_db      => true,
       }
       include ::apache
       class { '::aodh::wsgi::apache':
@@ -59,7 +58,6 @@ describe 'basic aodh' do
       class { '::aodh::notifier': }
       class { '::aodh::listener': }
       class { '::aodh::evaluator': }
-      class { '::aodh::db::sync': }
       EOS
 
 
